
//////////////////////////////////////////////////////////////
//
// Header file for MainWindowMainWindow
//
//    This class is a ViewKit VkWindow subclass
//
// Normally, very little in this file should need to be changed.
// Create/add/modify menus using the builder.
//
// Restrict changes to those sections between
// the "//--- Start/End editable code block" markers
// Doing so will allow you to make chnages using the builder
// without losing any changes you may have made manually
//
//////////////////////////////////////////////////////////////
#ifndef MAINWINDOWMAINWINDOW_H
#define MAINWINDOWMAINWINDOW_H
#include <Vk/VkWindow.h>

class VkMenuItem;
class VkMenuToggle;
class VkMenuConfirmFirstAction;
class VkSubMenu;
class VkRadioSubMenu;

//---- Start editable code block: headers and declarations

#include <bstring.h>
#include <BVN/Reactor.h>
#include <BVN/Acceptor.h>
#include <BVN/SOCK_Acceptor.h>
#include "BV_Svc_Handler.h"
#include "BV_Session_Control.h"
#include "BV_Tango_Control.h"
#include "MainForm.h"
#include "BV.h"
#include "BV_AudioApp.h"
#include "BV_VideoApp.h"

//---- End editable code block: headers and declarations


//---- MainWindowMainWindow class declaration

class MainWindowMainWindow: public VkWindow { 

  public:

    MainWindowMainWindow( const char * name, 
                          ArgList args = NULL,
                          Cardinal argCount = 0 );
    ~MainWindowMainWindow();
    const char *className();
    virtual Boolean okToQuit();

    //---- Start editable code block: MainWindowMainWindow public
    
    Reactor *getReactor();
    void playVideo();
    void stopVideo();
    void playAudio();
    void stopAudio();
    void updateOptions(Options *options);
    void setMicCutoffLevel(int level);

    BV_Tango_Control *tango_ctrl_;
    BV_Session_Control *session_control_;
    BV_AudioApp *audio_app_;
    BV_VideoApp *video_app_;

    //---- End editable code block: MainWindowMainWindow public


  protected:



    // Classes created by this class

    class MainForm *_mainForm;

    // Menu items created by this class
    VkSubMenu  *_filePane;
    VkMenuItem *_separator1;
    VkMenuItem *_resetButton;
    VkMenuItem *_exitButton;
    VkSubMenu  *_editPane;
    VkMenuItem *_optionsButton;
    VkSubMenu  *_viewPane;
    VkMenuItem *_audioPanelButton;
    VkMenuItem *_statButton;
    VkSubMenu  *_toolsPane;
    VkMenuItem *_chatButton;
    VkSubMenu  *_directoryPane;
    VkMenuItem *_entry;
    VkMenuItem *_usersButton;
    VkMenuItem *_confButton;

    // Menu Operations

    virtual void audioPanel ( Widget, XtPointer );
    virtual void chat ( Widget, XtPointer );
    virtual void conf ( Widget, XtPointer );
    virtual void options ( Widget, XtPointer );
    virtual void overview ( Widget, XtPointer );
    virtual void quit ( Widget, XtPointer );
    virtual void reset ( Widget, XtPointer );
    virtual void statistics ( Widget, XtPointer );
    virtual void users ( Widget, XtPointer );


    //---- Start editable code block: MainWindowMainWindow protected

    //---- End editable code block: MainWindowMainWindow protected


  private:


    // Callbacks to interface with Motif

    static void audioPanelCallback ( Widget, XtPointer, XtPointer );
    static void chatCallback ( Widget, XtPointer, XtPointer );
    static void confCallback ( Widget, XtPointer, XtPointer );
    static void optionsCallback ( Widget, XtPointer, XtPointer );
    static void overviewCallback ( Widget, XtPointer, XtPointer );
    static void quitCallback ( Widget, XtPointer, XtPointer );
    static void resetCallback ( Widget, XtPointer, XtPointer );
    static void statisticsCallback ( Widget, XtPointer, XtPointer );
    static void usersCallback ( Widget, XtPointer, XtPointer );

    static String      _defaultMainWindowMainWindowResources[];

    //---- Start editable code block: MainWindowMainWindow private

    Reactor *reactor_;
    Acceptor <BV_Svc_Handler, SOCK_Acceptor> *acceptor_;

    //---- End editable code block: MainWindowMainWindow private


};
#endif
